@@ -90,7 +90,7 @@ class DDBMethodChooser:
 		pc = []
 		for p in path:
 			pc += p if isinstance(p,  list) else [p]
-		self.path = utils.to_path_str([str(p) for p in pc])
+		self.path = "/".join([str(p) for p in pc])
 		self.key = key
 		self.where = where
 		self.op_type = OperationType(self.path, self.key, self.where)
@@ -112,8 +112,7 @@ class DDBMethodChooser:
 		if self.where is not None:
 			raise RuntimeError("DDB.at(where=...).exists() cannot be used with the where parameter")
 
-		occurs = len(utils.find(self.path)) > 0
-		if not occurs:
+		if len(utils.find(self.path)) == 0:
 			return False
 		if self.key is None:
 			return True
@@ -191,11 +190,11 @@ class DDBMethodChooser:
 					data[k] = v
 
 		elif self.op_type.dir_normal:
-			pattern_paths = utils.expand_find_path_pattern(self.path)
+			pattern_paths = utils.find(self.path)
 			data = {n.split("/")[-1]: io_safe.read(n) for n in pattern_paths}
 
 		elif self.op_type.dir_where:
-			for db_name in utils.expand_find_path_pattern(self.path):
+			for db_name in utils.find(self.path):
 				k, v = db_name.split("/")[-1], io_safe.read(db_name)
 				if self.where(k, type_cast(v)):
 					data[k] = v
